#!/usr/bin/env bash

#SHOULD BE 0 IN RELEASE!!!
show_watch=0

sleep_watch=0.3

function watch() {
  if [[ $show_watch -eq 1 ]]; then
    echo "$@"
    [[ $sleep_watch != 0 ]] && sleep $sleep_watch
  fi
}

function expand_gpu_list() {
  for e in `echo $1 | tr ',' ' '`; do
    if [[ $e =~ '-' ]]; then
      eval "for i in {${e/-/..}}; do echo \$i; done"
    else
      echo $e
    fi
  done
}

function miner_ver() {
  local MINER_VER=$BZMINER_VER
  [[ -z $MINER_VER ]] && MINER_VER=$MINER_LATEST_VER
  echo $MINER_VER
}

function miner_config_echo() {
  local MINER_VER=$(miner_ver)
  miner_echo_config_file "/hive/miners/$MINER_NAME/$MINER_VER/config.json"
}

function miner_config_gen() {
  local MINER_CONFIG="$MINER_DIR/$MINER_VER/config.txt"
  mkfile_from_symlink $MINER_CONFIG

  conf=`cat $MINER_DIR/$MINER_VER/config_global.json | envsubst`

  #merge user config options into main config
  if [[ ! -z $BZMINER_USER_CONFIG ]]; then
    while read -r line; do
      [[ -z $line ]] && continue
      conf=$(jq -s '.[0] * .[1]' <<< "$conf {$line}")
    done <<< "$BZMINER_USER_CONFIG"
  fi

  #merge settings into main config
  [[ -z $BZMINER_ALGO ]] && BZMINER_ALGO="ethash"
  local param='"algorithm": "'$BZMINER_ALGO'"'
  conf=$(jq -s '.[0] * .[1]' <<< "$conf {$param}")

  if [[ -z $BZMINER_TEMPLATE ]]; then
    echo -e "${YELLOW} WALLET is empty${NOCOLOR}"
    return 1
  else
    param='"wallet": "'$BZMINER_TEMPLATE'"'
    conf=$(jq -s '.[0] * .[1]' <<< "$conf {$param}")
  fi

  if [[ -n $BZMINER_WORKER ]]; then
    param='"rig": "'$BZMINER_WORKER'"'
    conf=$(jq -s '.[0] * .[1]' <<< "$conf {$param}")
  fi

  #merge pools into main config
  if [[ -z $BZMINER_URL ]]; then
    echo -e "${YELLOW} Pool is empty${NOCOLOR}"
    return 1
  fi
  local protocol=
  local url=

  if [[ $BZMINER_URL == *://* ]]; then
    if [[ $BZMINER_URL =~ ([A-Za-z0-9]+)\+([A-Za-z]+)://([^[:space:]]+) ]]; then
      protocol=${BASH_REMATCH[1]}
      url=${BASH_REMATCH[3]}
    else
      echo -e "${YELLOW} Pool address parsing error${NOCOLOR}"
      return 1
    fi
  else
    protocol="stratum"
    url=$BZMINER_URL
  fi
  [[ $BZMINER_TLS -eq 1 ]] && protocol+="+ssl://" || protocol+="+tcp://"
#  [[ -n $BZMINER_PASS ]] && protocol+="${BZMINER_TEMPLATE}.${BZMINER_WORKER}:${BZMINER_PASS}@"

  if [[ -n $BZMINER_PASS ]]; then
    param='"pool_password": "'$BZMINER_PASS'"'
    conf=$(jq -s '.[0] * .[1]' <<< "$conf {$param}")
  fi

  param='"pool": "'${protocol}${url}'"'
#  param='"pool": "'${url}'"'
  conf=$(jq -s '.[0] * .[1]' <<< "$conf {$param}")

  if [[ -n $BZMINER_DISABLE_GPUS ]]; then
    local gpus='[]'
    for gpu in `expand_gpu_list ${BZMINER_DISABLE_GPUS// }`; do #delete spaces in gpuslist
      watch gpu $gpu
      gpu_bus_id=`cat /run/hive/gpu-detect.json | jq -r ".[$gpu].busid" | cut -d '.' -f 1`
      watch gpu_bus_id $gpu_bus_id
      gpu_bus_id_1=`cut -d ':' -f 1 <<< "$gpu_bus_id"`
      watch gpu_bus_id_1 $gpu_bus_id_1
      gpu_bus_id_2=`cut -d ':' -f 2 <<< "$gpu_bus_id"`
      watch gpu_bus_id_2 $gpu_bus_id_2
      (( gpu_bus_num_1=0x$gpu_bus_id_1 ))
      watch gpu_bus_num_1 $gpu_bus_num_1
      (( gpu_bus_num_2=0x$gpu_bus_id_2 ))
      watch gpu_bus_num_2 $gpu_bus_num_2
      gpu_bus_num=${gpu_bus_num_1}:${gpu_bus_num_2}
      watch gpu_bus_num $gpu_bus_num

      param='{"uid": "'$gpu_bus_num'", "start_mining": false}'
      watch param $param

      gpus=`jq --null-input --argjson gpus "$gpus" --argjson param "$param" '$gpus + [$param]'`
      watch "gpus" "$gpus"
      #gpus=$(jq -s '.[0] * .[1]' <<< "$gpus {$param}")
    done

    # conf=$(jq -s '.[0] * .[1]' <<< "$conf {"device_overrides": $gpus}")
    gpus=`jq --null-input --argjson gpus "$gpus" '{"device_overrides": $gpus}'`
    conf=$(jq -s '.[0] * .[1]' <<< "$conf $gpus")
  fi

  echo "$conf" | jq . > $MINER_CONFIG

  [[ $show_watch -eq 1 ]] && sleep 5

  exit 0
}
