#!/usr/bin/env bash

stats_raw=`curl --connect-timeout 2 --max-time $API_TIMEOUT --silent --noproxy '*' http://127.0.0.1:$MINER_API_PORT/status`
if [[ $? -ne 0  || -z $stats_raw ]]; then
  echo -e "${YELLOW}Failed to read $miner stats_raw from localhost:${MINER_API_PORT}${NOCOLOR}"
else
  khs=`echo "$stats_raw" | jq -r '.devices[].hashrate' | awk '{s+=$1} END {printf("%.4f",s/1000)}'` #sum up and convert to khs
  local hs=`echo "$stats_raw" | jq -rc '[.devices[].hashrate]'`
  local hs_units="hs"
  local a=`echo "$stats_raw" | jq -rc '.devices[].valid_solutions' | awk '{s+=$1} END {print s}'` #sum up shares
  local r=`echo "$stats_raw" | jq -rc '.devices[].rejected_solutions' | awk '{s+=$1} END {print s}'` #sum up shares
  local i=`echo "$stats_raw" | jq -rc '.devices[].invalid_solutions' | awk '{s+=$1} END {print s}'` #sum up shares
#  local ag=`jq -rc '[.devices[].valid_solutions]' <<< $stats_raw`
#  local rg=`jq -rc '[.devices[].rejected_solutions]' <<< $stats_raw`
#  local ig=`jq -rc '[.devices[].invalid_solutions]' <<< $stats_raw`
  local ig=`jq -rc '.devices[].invalid_solutions' <<< $stats_raw`
  ig=`echo $ig | tr " " ";"`

#  pool=`jq -r '.pools[0].pool' <<< $stats_raw`

  ver=`miner_ver`
  local fan=`jq -r '[.devices[].fan]' <<< $stats_raw`
  local temp=`jq -r '[.devices[].coretemp]' <<< $stats_raw`
  local bus_numbers=`jq -r '[.devices[].pcibusid]' <<< $stats_raw`
  local upt=`jq -r '.uptime' <<< $stats_raw`
  d=`echo $upt | awk '{print $1}' | tr -d 'd'`
  h=`echo $upt | awk '{print $2}' | tr -d 'h'`
  m=`echo $upt | awk '{print $3}' | tr -d 'm'`
  s=`echo $upt | awk '{print $4}' | tr -d 's'`
  ((upt=s+m*60+h*3600+d*86400))

  stats=$(jq -nc \
             --arg total_khs "$khs" \
             --argjson hs "$hs" \
             --arg hs_units "$hs_units" \
             --argjson temp "$temp" \
             --argjson fan "$fan" \
             --arg a "$a" --arg r "$r" --arg i "$i" --arg ig "$ig" \
             --argjson bus_numbers "$bus_numbers" \
             --arg algo "$BZMINER_ALGO"  \
             --arg ver "$ver" \
             --arg uptime "$upt" \
             '{$total_khs, $hs, $hs_units, ar: [$a, $r, $i, $ig], $algo,
               $bus_numbers, $temp, $fan, $uptime, $ver}')
fi

# debug output
#echo "temp:         $a_temp"
#echo "fan:          $a_fans"
#echo "bus_numbers:  $a_bnum"
#echo "a:            $a"
#echo "r:            $r"
#echo "i:            $i"
#echo "ig:           $ig"
#echo "hs:           $hs"
#echo "stats:        $stats"
#echo "khs:          $khs"
